==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Input/gme/translations/gme_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="39"/>
        <source>GME Plugin</source>
        <translation>Wtyczka GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="42"/>
        <source>Game Music Files</source>
        <translation>Game Music Files</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="106"/>
        <source>About GME Audio Plugin</source>
        <translation>O wtyczce dźwiękowej GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="107"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>Wtyczka dźwiękowa GME dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="108"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>Ta wtyczka używa biblioteki Game_Music_Emu do odtwarzania plików muzycznych z gier</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="109"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>GME Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Fadeout length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Enable fadeout</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/Input/gme/translations/gme_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="38"/>
        <source>GME Plugin</source>
        <translation>Wtyczka GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="41"/>
        <source>Game Music Files</source>
        <translation>Pliki muzyczne z gier</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="103"/>
        <source>About GME Audio Plugin</source>
        <translation>O wtyczce dźwiękowej GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="104"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>Wtyczka dźwiękowa GME dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="105"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>Ta wtyczka używa biblioteki Game_Music_Emu do odtwarzania plików muzycznych z gier</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="106"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Napisana przez: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>GME Plugin Settings</source>
        <translation>Ustawienia wtyczki GME</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Fadeout length:</source>
        <translation>Długość ściszenia:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Enable fadeout</source>
        <translation>Włącz ściszenie</translation>
    </message>
</context>
</TS>
